@@ -67,7 +67,7 @@ r2_hf <- function(genotypes, type = c("msats", "snps"), nboot = NULL,
     calc_r2 <- function(gtypes) {
             g2 <- g2_fun(gtypes)[["g2"]]
             # according to the miller paper, negative g2s are set to r2 = 0.
-            if (g2 < 0) return(r2 <- 0)
+            if (is.na(g2) | (g2 < 0)) return(0)
             var_sh <- stats::var(sMLH(gtypes))
             r2 <- g2/var_sh
             if (r2 > 1) r2 <- 1
